@@ -1,6 +1,7 @@
 ENV["NOTURN"] = "1"
+# elasticsearch-dsl is not compatible with test-unit 3
 modules = ['elasticsearch', 'elasticsearch-transport', 'elasticsearch-api',
-           'elasticsearch-extensions','elasticsearch-watcher','elasticsearch-dsl']
+           'elasticsearch-extensions','elasticsearch-watcher']
 $: << "."
 modules.each { |m| $: << "#{m}/lib" }
 modules.each do |m|
